@@ -1,7 +1,7 @@
 from .info import InfoAccess
 from .volumes import VolumesAccess
 from ..base import Database
-from ..tables import MultiClassTable, MultiClassExternalTable
+from ..tables import KeyValueTable, MultiClassTable, MultiClassExternalTable
 from ...models import Chapter
 
 
@@ -15,7 +15,7 @@ class WebNovelData(Database):
         self.pending = MultiClassTable(self.db, 'pending', Chapter, ['index', 'no', 'url'], 'url')
         self.chapters = MultiClassExternalTable(
             self.db, self.path.parent, 'chapters', Chapter,
-            ['index', 'no', 'title', 'paragraphs', 'url'], ['index'], 'url',
+            ['index', 'no', 'title', 'paragraphs', 'url'], 'url',
             naming_scheme=lambda c: str(c.index),
-            on_missing=lambda c: self.pending.put(c),
         )
+        self.misc = KeyValueTable(self.db, 'misc')
