@@ -1,10 +1,11 @@
 from pathlib import Path
+from urllib.parse import urlparse
 
 import requests
 
-from . import Epub
 from .concurrent import ConcurrentActionsController
 from .database import NovelData
+from .epub import NovelEpub
 from .sources import sources
 from .template import NovelSaveTemplate
 from .tools import StringTools, UiTools
@@ -15,8 +16,9 @@ class SourceNovelSave(NovelSaveTemplate):
     def __init__(self, url, directory=None):
         super(SourceNovelSave, self).__init__(url, None, None, directory)
 
-        self.db = self.open_db()
         self.source = self.parse_source()
+        self.netloc_slug = StringTools.slugify(urlparse(self.source.base).netloc, replace='_')
+        self.db = self.open_db()
 
     def update(self, force_cover=False):
 
@@ -36,7 +38,7 @@ class SourceNovelSave(NovelSaveTemplate):
         self.db.novel.set(novel)
 
         # update_pending
-        saved = self.db.chapters.all_basic()
+        saved = self.db.chapters.all()
         pending = list(set(chapters).difference(saved))
 
         self.db.pending.truncate()
@@ -50,7 +52,6 @@ class SourceNovelSave(NovelSaveTemplate):
         if limit and limit <= 0:
             UiTools.print_error("'limit' must be greater than 0")
 
-        self.db.chapters.check()  # check if any external files are missing
         pending = self.db.pending.all()
         if not pending:
             UiTools.print_error('No pending chapters')
@@ -78,6 +79,9 @@ class SourceNovelSave(NovelSaveTemplate):
             for chapter in pending:
                 controller.add(chapter)
 
+            # set new downloads flag to true
+            self.db.misc.put(self.IS_CHAPTERS_UPDATED, True)
+
             # start downloading
             for chapter in controller.iter():
                 # debug
@@ -88,18 +92,19 @@ class SourceNovelSave(NovelSaveTemplate):
                 if self.verbose:
                     brush.value += 1
                     brush.desc = f'[{brush.value}/{brush.total}] {chapter.url}'
-                else:
-                    print(f'[{str(chapter.index).zfill(4)}] Downloaded {chapter.url}')
 
-                # get data
-                self.db.chapters.insert(chapter)
+                self.db.chapters.put(chapter)
 
                 # at last remove chapter from pending
                 self.db.pending.remove(chapter.url)
 
-    def create_epub(self):
+        # ensure all operations are done
+        self.db.chapters.flush()
+
+    def create_epub(self, force=False):
         UiTools.print_info('Packing epub...')
-        path = Epub().create(
+
+        epub = NovelEpub(
             novel=self.db.novel.parse(),
             cover=self.cover_path(),
             volumes={},
@@ -107,13 +112,26 @@ class SourceNovelSave(NovelSaveTemplate):
             save_path=self.db.path.parent
         )
 
-        UiTools.print_success(f'Saved to {path}')
+        # get new downloads flag
+        is_updated = self.db.misc.get(self.IS_CHAPTERS_UPDATED, default=False)
+
+        # check flags and whether the epub already exists
+        if not is_updated and not force and epub.path.exists():
+            UiTools.print_info('Aborted. No changes to chapter database')
+            return
+
+        epub.create()
+
+        # reset new downloads flag
+        self.db.misc.put(self.IS_CHAPTERS_UPDATED, False)
+
+        UiTools.print_success(f'Saved to {epub.path}')
 
     def open_db(self):
         # trailing slash adds nothing
         url = self.url.rstrip('/ ')
         folder_name = StringTools.slugify(url.split('/')[-1])
-        directory = Path(self.user.directory.get()) / Path(folder_name)
+        directory = Path(self.user.directory.get()) / Path(self.netloc_slug) / Path(folder_name)
 
         return NovelData(directory)
 
