@@ -1,3 +1,5 @@
+import logging
+from datetime import datetime
 from pathlib import Path
 
 from .database.config import UserConfig
@@ -7,6 +9,8 @@ from .tools import UiTools
 class NovelSaveTemplate:
     verbose = False
 
+    IS_CHAPTERS_UPDATED = 'is_cu'
+
     def __init__(self, url, username, password, directory=None):
         self.url = url
         self.username = username
@@ -23,6 +27,15 @@ class NovelSaveTemplate:
 
             self.user.directory.put(str(path))
 
+        # initialize logger
+        logfile = self.user.directory.get() / Path('logs') / f"{datetime.today().strftime('%Y-%m-%d')}.log"
+        logfile.parent.mkdir(parents=True, exist_ok=True)
+        logging.basicConfig(
+            filename=logfile,
+            filemode='a',
+            format='%(asctime)s %(levelname)s - %(message)s',
+        )
+
     def update(self, force_cover=False):
         """
         Update novel data
@@ -42,9 +55,11 @@ class NovelSaveTemplate:
         """
         raise NotImplementedError
 
-    def create_epub(self):
+    def create_epub(self, force=False):
         """
         create epub from current data
+
+        :param force: force create and overwrite the existing epub
         """
         raise NotImplementedError
 
