@@ -8,7 +8,7 @@ from webnovel.tools import UrlTools
 
 from .concurrent import ConcurrentActionsController
 from .database import WebNovelData
-from .epub import Epub
+from .epub import NovelEpub
 from .models import Chapter
 from .template import NovelSaveTemplate
 from .tools import UiTools
@@ -24,6 +24,7 @@ class WebNovelSave(NovelSaveTemplate):
         super(WebNovelSave, self).__init__(url, username, password, directory)
 
         self.novel_id = UrlTools.from_novel_url(url)
+        self.netloc_slug = "www_webnovel_com"
 
     def update(self, force_cover=False):
         # get api
@@ -54,7 +55,7 @@ class WebNovelSave(NovelSaveTemplate):
             data.volumes.set_volume(volume, [c.id for c in chapters])
 
         # update pending
-        saved = data.chapters.all_basic()
+        saved = data.chapters.all()
         pending = list({self.to_chapter(c) for v in toc.values() for c in v if not c.locked}.difference(saved))
 
         data.pending.truncate()
@@ -72,7 +73,6 @@ class WebNovelSave(NovelSaveTemplate):
             UiTools.print_error("'limit' must be greater than 0")
 
         data = self.open_db()
-        data.chapters.check()  # check if any external files are missing
         pending = data.pending.all()
         if len(pending) <= 0:
             UiTools.print_error('No pending chapters')
@@ -103,29 +103,32 @@ class WebNovelSave(NovelSaveTemplate):
             for chapter in pending:
                 controller.add(self.novel_id, chapter.index)
 
+            # set new downloads flag to true
+            data.misc.put(self.IS_CHAPTERS_UPDATED, True)
+
             # start downloading
             for chapter in controller.iter():
                 # update brush
                 if self.verbose:
                     brush.value += 1
                     brush.desc = f'[{brush.value}/{brush.total}] {chapter.url}'
-                else:
-                    print(f'[{chapter.index}] Downloaded {chapter.url}')
 
-                # get data
-                data.chapters.insert(chapter)
+                data.chapters.put(chapter)
 
                 # at last
                 data.pending.remove(chapter.url)
 
-    def create_epub(self):
+        # ensure all tasks are done
+        data.chapters.flush()
+
+    def create_epub(self, force=False):
         """
         Create epub with current data
         """
         data = self.open_db()
 
         UiTools.print_info('Packing epub...')
-        path = Epub().create(
+        epub = NovelEpub(
             novel=data.info.get_info(),
             cover=self.cover_path(),
             volumes=data.volumes.all(),
@@ -133,7 +136,20 @@ class WebNovelSave(NovelSaveTemplate):
             save_path=self.path()
         )
 
-        UiTools.print_success(f'Saved to {path}')
+        # get new downloads flag
+        is_updated = data.misc.get(self.IS_CHAPTERS_UPDATED, default=False)
+
+        # check flags and whether the epub already exists
+        if not is_updated and not force and epub.path.exists():
+            UiTools.print_info('Aborted. No changes to chapter database')
+            return
+
+        epub.create()
+
+        # reset new downloads flag
+        data.misc.put(self.IS_CHAPTERS_UPDATED, False)
+
+        UiTools.print_success(f'Saved to {epub.path}')
 
     def get_api(self) -> ParsedApi:
         """
@@ -170,7 +186,7 @@ class WebNovelSave(NovelSaveTemplate):
         return self.path() / Path('cover.jpg')
 
     def path(self):
-        path = Path(self.user.directory.get()) / Path(f'n{self.novel_id}')
+        path = Path(self.user.directory.get()) / Path(self.netloc_slug) / Path(f'n{self.novel_id}')
         path.mkdir(parents=True, exist_ok=True)
 
         return path
